% Auto-generated chapter 83 for bukhari
% Hadiths in this chapter: 84

\hadithdefcmd{bukhari}{6621}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ لَمْ يَكُنْ يَحْنَثُ فِي يَمِينٍ قَطُّ، حَتَّى أَنْزَلَ اللَّهُ كَفَّارَةَ الْيَمِينِ وَقَالَ لاَ أَحْلِفُ عَلَى يَمِينٍ فَرَأَيْتُ غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ، وَكَفَّرْتُ عَنْ يَمِينِي‏.‏\hadithno{6621}\hadithtrans{Narrated `Aisha:Abu Bakr As-Siddiq had never broken his oaths till Allah revealed the expiation for the oaths. Then he said, "If I take an oath to do something and later on I find something else better than the first one, then I do what is better and make expiation for my oath}}
\hadithdefcmd{bukhari}{6622}{حَدَّثَنَا أَبُو النُّعْمَانِ، مُحَمَّدُ بْنُ الْفَضْلِ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا الْحَسَنُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَمُرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ الرَّحْمَنِ بْنَ سَمُرَةَ لاَ تَسْأَلِ الإِمَارَةَ، فَإِنَّكَ إِنْ أُوتِيتَهَا عَنْ مَسْأَلَةٍ وُكِلْتَ إِلَيْهَا، وَإِنْ أُوتِيتَهَا مِنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا، وَإِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا، فَكَفِّرْ عَنْ يَمِينِكَ، وَأْتِ الَّذِي هُوَ خَيْرٌ ‏"‏‏.‏\hadithno{6622}\hadithtrans{Narrated `Abdur-Rahman bin Samura:The Prophet (ﷺ) said, "O `Abdur-Rahman bin Samura! Do not seek to be a ruler, because if you are given authority for it, then you will be held responsible for it, but if you are given it without asking for it, then you will be helped in it (by Allah): and whenever you take an oath to do something and later you find that something else is better than the first, then do the better one and make expiation for your oath}}
\hadithdefcmd{bukhari}{6623}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي رَهْطٍ مِنَ الأَشْعَرِيِّينَ أَسْتَحْمِلُهُ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ، وَمَا عِنْدِي مَا أَحْمِلُكُمْ عَلَيْهِ ‏"‏‏.‏ قَالَ ثُمَّ لَبِثْنَا مَا شَاءَ اللَّهُ أَنْ نَلْبَثَ، ثُمَّ أُتِيَ بِثَلاَثِ ذَوْدٍ غُرِّ الذُّرَى فَحَمَلَنَا عَلَيْهَا فَلَمَّا انْطَلَقْنَا قُلْنَا أَوْ قَالَ بَعْضُنَا وَاللَّهِ لاَ يُبَارَكُ لَنَا، أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم نَسْتَحْمِلُهُ، فَحَلَفَ أَنْ لاَ يَحْمِلَنَا ثُمَّ حَمَلَنَا، فَارْجِعُوا بِنَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَنُذَكِّرُهُ، فَأَتَيْنَاهُ فَقَالَ ‏"‏ مَا أَنَا حَمَلْتُكُمْ، بَلِ اللَّهُ حَمَلَكُمْ، وَإِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ كَفَّرْتُ عَنْ يَمِينِي، وَأَتَيْتُ الَّذِي هُوَ خَيْرٌ ‏"‏‏.‏ أَوْ ‏"‏ أَتَيْتُ الَّذِي هُوَ خَيْرٌ وَكَفَّرْتُ عَنْ يَمِينِي ‏"‏‏.‏\hadithno{6623}\hadithtrans{Narrated Abu Musa:I went to the Prophet (ﷺ) along with a group of Al-Ash`ariyin in order to request him to provide us with mounts. He said, "By Allah, I will not provide you with mounts and I haven't got anything to mount you on." Then we stayed there as long as Allah wished us to stay, and then three very nice looking she-camels were brought to him and he made us ride them. When we left, we, or some of us, said, "By Allah, we will not be blessed, as we came to the Prophet (ﷺ) asking him for mounts, and he swore that he would not give us any mounts but then he did give us. So let us go back to the Prophet (ﷺ) and remind him (of his oath)." When we returned to him (and reminded him of the fact), he said, "I did not give you mounts, but it is Allah Who gave you. By Allah, Allah willing, if I ever take an oath to do something and then I find something else than the first, I will make expiation for my oath and do the thing which is better (or do something which is better and give the expiation for my oath)}}
\hadithdefcmd{bukhari}{6624}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{6624}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "We (Muslims) are the last in the world, but will be foremost on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6625}{فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ لأَنْ يَلِجَّ أَحَدُكُمْ بِيَمِينِهِ فِي أَهْلِهِ آثَمُ لَهُ عِنْدَ اللَّهِ مِنْ أَنْ يُعْطِيَ كَفَّارَتَهُ الَّتِي افْتَرَضَ اللَّهُ عَلَيْهِ ‏"‏‏.‏\hadithno{6625}\hadithtrans{Allah's Messenger (ﷺ) also said:"By Allah, if anyone of you insists on fulfilling an oath by which he may harm his family, he commits a greater sin in Allah's sight than that of dissolving his oath and making expiation for it}}
\hadithdefcmd{bukhari}{6626}{حَدَّثَنِي إِسْحَاقُ يَعْنِي ابْنَ إِبْرَاهِيمَ، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَلَجَّ فِي أَهْلِهِ بِيَمِينٍ فَهْوَ أَعْظَمُ إِثْمًا، لِيَبَرَّ ‏"‏‏.‏ يَعْنِي الْكَفَّارَةَ‏.‏\hadithno{6626}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Anyone who takes an oath through which his family may be harmed, and insists on keeping it, he surely commits a sin greater (than that of dissolving his oath). He should rather compensate for that oath by making expiation}}
\hadithdefcmd{bukhari}{6627}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْثًا وَأَمَّرَ عَلَيْهِمْ أُسَامَةَ بْنَ زَيْدٍ، فَطَعَنَ بَعْضُ النَّاسِ فِي إِمْرَتِهِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنْ كُنْتُمْ تَطْعَنُونَ فِي إِمْرَتِهِ فَقَدْ كُنْتُمْ تَطْعَنُونَ، فِي إِمْرَةِ أَبِيهِ مِنْ قَبْلُ، وَايْمُ اللَّهِ إِنْ كَانَ لَخَلِيقًا لِلإِمَارَةِ، وَإِنْ كَانَ لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ، وَإِنَّ هَذَا لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ بَعْدَهُ ‏"‏‏.‏\hadithno{6627}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) sent an army detachment and made Usama bin Zaid its commander. Some people criticized (spoke badly of) Usama's leadership. So Allah's Messenger (ﷺ) got up saying, "If you people are criticizing Usama's leadership, you have already criticized the leadership of his father before. But Waaimullah (i.e., By Allah), he (i.e. Zaid) deserved the leadership, and he was one of the most beloved persons to me; and now this (his son Usama) is one of the dearest persons to me after him." (See Hadith No. 765, Vol)}}
\hadithdefcmd{bukhari}{6628}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ سُفْيَانَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَتْ يَمِينُ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لاَ وَمُقَلِّبِ الْقُلُوبِ ‏"‏‏.‏\hadithno{6628}\hadithtrans{Narrated Ibn `Umar:The oath of the Prophet (ﷺ) used to be: "No, by Him who turns the hearts}}
\hadithdefcmd{bukhari}{6629}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ جَابِرِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا هَلَكَ قَيْصَرُ فَلاَ قَيْصَرَ بَعْدَهُ، وَإِذَا هَلَكَ كِسْرَى فَلاَ كِسْرَى بَعْدَهُ، وَالَّذِي نَفْسِي بِيَدِهِ لَتُنْفَقَنَّ كُنُوزُهُمَا فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{6629}\hadithtrans{Narrated Jabir bin Samura:The Prophet (ﷺ) said, "If Caesar is ruined, there will be no Caesar after him; and if Khosrau is ruined, there will be no Khosrau, after him; and, by Him in Whose Hand my soul is, surely you will spend their treasures in Allah's Cause}}
\hadithdefcmd{bukhari}{6630}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا هَلَكَ كِسْرَى فَلاَ كِسْرَى بَعْدَهُ، وَإِذَا هَلَكَ قَيْصَرُ فَلاَ قَيْصَرَ بَعْدَهُ، وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَتُنْفَقَنَّ كُنُوزُهُمَا فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{6630}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If Khosrau is ruined, there will be no Khosrau after him; and if Caesar is ruined, there will be no Caesar after him. By Him in Whose Hand Muhammad's soul is, surely you will spend their treasures in Allah's Cause}}
\hadithdefcmd{bukhari}{6631}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ يَا أُمَّةَ مُحَمَّدٍ وَاللَّهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَبَكَيْتُمْ كَثِيرًا، وَلَضَحِكْتُمْ قَلِيلاً ‏"‏‏.‏\hadithno{6631}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "O followers of Muhammad! By Allah, if you knew what I know, you would weep much and laugh little}}
\hadithdefcmd{bukhari}{6632}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حَيْوَةُ، قَالَ حَدَّثَنِي أَبُو عَقِيلٍ، زُهْرَةُ بْنُ مَعْبَدٍ أَنَّهُ سَمِعَ جَدَّهُ عَبْدَ اللَّهِ بْنَ هِشَامٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم وَهْوَ آخِذٌ بِيَدِ عُمَرَ بْنِ الْخَطَّابِ فَقَالَ لَهُ عُمَرُ يَا رَسُولَ اللَّهِ لأَنْتَ أَحَبُّ إِلَىَّ مِنْ كُلِّ شَىْءٍ إِلاَّ مِنْ نَفْسِي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ وَالَّذِي نَفْسِي بِيَدِهِ حَتَّى أَكُونَ أَحَبَّ إِلَيْكَ مِنْ نَفْسِكَ ‏"‏‏.‏ فَقَالَ لَهُ عُمَرُ فَإِنَّهُ الآنَ وَاللَّهِ لأَنْتَ أَحَبُّ إِلَىَّ مِنْ نَفْسِي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الآنَ يَا عُمَرُ ‏"‏‏.‏\hadithno{6632}\hadithtrans{Narrated `Abdullah bin Hisham:We were with the Prophet (ﷺ) and he was holding the hand of `Umar bin Al-Khattab. `Umar said to Him, "O Allah's Messenger (ﷺ)! You are dearer to me than everything except my own self." The Prophet (ﷺ) said, "No, by Him in Whose Hand my soul is, (you will not have complete faith) till I am dearer to you than your own self." Then `Umar said to him, "However, now, by Allah, you are dearer to me than my own self." The Prophet (ﷺ) said, "Now, O `Umar, (now you are a believer)}}
\hadithdefcmd{bukhari}{6634}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ وَقَالَ الآخَرُ وَهْوَ أَفْقَهُهُمَا أَجَلْ يَا رَسُولَ اللَّهِ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَائْذَنْ لِي أَنْ أَتَكَلَّمَ‏.‏ قَالَ ‏"‏ تَكَلَّمْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا ـ قَالَ مَالِكٌ وَالْعَسِيفُ الأَجِيرُ ـ زَنَى بِامْرَأَتِهِ، فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَجَارِيَةٍ لِي، ثُمَّ إِنِّي سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّ مَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَإِنَّمَا الرَّجْمُ عَلَى امْرَأَتِهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا غَنَمُكَ وَجَارِيَتُكَ فَرَدٌّ عَلَيْكَ ‏"‏‏.‏ وَجَلَدَ ابْنَهُ مِائَةً وَغَرَّبَهُ عَامًا، وَأُمِرَ أُنَيْسٌ الأَسْلَمِيُّ أَنْ يَأْتِيَ امْرَأَةَ الآخَرِ، فَإِنِ اعْتَرَفَتْ رَجَمَهَا، فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏\hadithno{6634}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Two men had a dispute in the presence of Allah's Messenger (ﷺ). One of them said, "O Allah's Messenger (ﷺ)! Judge between us according to Allah's Laws." The other who was wiser, said, "Yes, O Allah's Apostle! Judge between us according to Allah's Laws and allow me to speak. The Prophet (ﷺ) said, "Speak." He said, "My son was a laborer serving this (person) and he committed illegal sexual intercourse with his wife, The people said that my son is to be stoned to death, but I ransomed him with one-hundred sheep and a slave girl. Then I asked the learned people, who informed me that my son should receive one hundred lashes and will be exiled for one year, and stoning will be the lot for the man's wife." Allah's Messenger (ﷺ) said, "Indeed, by Him in Whose Hand my soul is, I will judge between you according to Allah's Laws: As for your sheep and slave girl, they are to be returned to you." Then he scourged his son one hundred lashes and exiled him for one year. Then Unais Al- Aslami was ordered to go to the wife of the second man, and if she confessed (the crime), then stone her to death. She did confess, so he stoned her to death}}
\hadithdefcmd{bukhari}{6635}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَهْبٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ أَبِي يَعْقُوبَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَرَأَيْتُمْ إِنْ كَانَ أَسْلَمُ وَغِفَارُ وَمُزَيْنَةُ وَجُهَيْنَةُ خَيْرًا مِنْ تَمِيمٍ وَعَامِرِ بْنِ صَعْصَعَةَ وَغَطَفَانَ وَأَسَدٍ، خَابُوا وَخَسِرُوا ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهُمْ خَيْرٌ مِنْهُمْ ‏"‏‏.‏\hadithno{6635}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "Do you think if the tribes of Aslam, Ghifar, Muzaina and Juhaina are better than the tribes of Tamim, 'Amir bin Sa'sa'a, Ghatfan and Asad, they (the second group) are despairing and losing?" They (the Prophet's companions) said, "Yes, (they are)." He said, "By Him in Whose Hand my soul is, they (the first group) are better than them (the second group)}}
\hadithdefcmd{bukhari}{6636}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ عَامِلاً فَجَاءَهُ الْعَامِلُ حِينَ فَرَغَ مِنْ عَمَلِهِ فَقَالَ يَا رَسُولَ اللَّهِ هَذَا لَكُمْ، وَهَذَا أُهْدِيَ لِي‏.‏ فَقَالَ لَهُ ‏"‏ أَفَلاَ قَعَدْتَ فِي بَيْتِ أَبِيكَ وَأُمِّكَ فَنَظَرْتَ أَيُهْدَى لَكَ أَمْ لاَ ‏"‏‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشِيَّةً بَعْدَ الصَّلاَةِ فَتَشَهَّدَ وَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ، فَمَا بَالُ الْعَامِلِ نَسْتَعْمِلُهُ، فَيَأْتِينَا فَيَقُولُ هَذَا مِنْ عَمَلِكُمْ، وَهَذَا أُهْدِيَ لِي‏.‏ أَفَلاَ قَعَدَ فِي بَيْتِ أَبِيهِ وَأُمِّهِ فَنَظَرَ هَلْ يُهْدَى لَهُ أَمْ لاَ، فَوَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لاَ يَغُلُّ أَحَدُكُمْ مِنْهَا شَيْئًا، إِلاَّ جَاءَ بِهِ يَوْمَ الْقِيَامَةِ يَحْمِلُهُ عَلَى عُنُقِهِ، إِنْ كَانَ بَعِيرًا جَاءَ بِهِ لَهُ رُغَاءٌ، وَإِنْ كَانَتْ بَقَرَةً جَاءَ بِهَا لَهَا خُوَارٌ، وَإِنْ كَانَتْ شَاةً جَاءَ بِهَا تَيْعَرُ، فَقَدْ بَلَّغْتُ ‏"‏‏.‏ فَقَالَ أَبُو حُمَيْدٍ ثُمَّ رَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ حَتَّى إِنَّا لَنَنْظُرُ إِلَى عُفْرَةِ إِبْطَيْهِ‏.‏ قَالَ أَبُو حُمَيْدٍ وَقَدْ سَمِعَ ذَلِكَ مَعِي زَيْدُ بْنُ ثَابِتٍ مِنَ النَّبِيِّ صلى الله عليه وسلم فَسَلُوهُ‏.‏\hadithno{6636}\hadithtrans{Narrated Abu Humaid As-Sa`idi:Allah's Messenger (ﷺ) employed an employee (to collect Zakat). The employee returned after completing his job and said, "O Allah's Messenger (ﷺ)! This (amount of Zakat) is for you, and this (other amount) was given to me as a present." The Prophet (ﷺ) said to him, "Why didn't you stay at your father's or mother's house and see if you would be given presents or not?" Then Allah's Messenger (ﷺ) got up in the evening after the prayer, and having testified that none has the right to be worshipped but Allah and praised and glorified Allah as He deserved, he said, "Now then ! What about an employee whom we employ and then he comes and says, 'This amount (of Zakat) is for you, and this (amount) was given to me as a present'? Why didn't he stay at the house of his father and mother to see if he would be given presents or not? By Him in Whose Hand Muhammad's soul is, none of you will steal anything of it (i.e. Zakat) but will bring it by carrying it over his neck on the Day of Resurrection. If it has been a camel, he will bring it (over his neck) while it will be grunting, and if it has been a cow, he will bring it (over his neck), while it will be mooing; and if it has been a sheep, he will bring it (over his neck) while it will be bleeding." The Prophet (ﷺ) added, "I have preached you (Allah's Message)." Abu Humaid said, "Then Allah's Messenger (ﷺ) raised his hands so high that we saw the whiteness of his armpits}}
\hadithdefcmd{bukhari}{6637}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَام ٌ ـ هُوَ ابْنُ يُوسُفَ ـ عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَبَكَيْتُمْ كَثِيرًا، وَلَضَحِكْتُمْ قَلِيلاً ‏"‏‏.‏\hadithno{6637}\hadithtrans{Narrated Abu Huraira:Abu-l-Qasim (the Prophet) said, "By Him in Whose Hand Muhammad's soul is, if you know that which I know, you would weep much and laugh little}}
\hadithdefcmd{bukhari}{6638}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ، عَنْ أَبِي ذَرٍّ، قَالَ انْتَهَيْتُ إِلَيْهِ وَهُوَ يَقُولُ فِي ظِلِّ الْكَعْبَةِ ‏"‏ هُمُ الأَخْسَرُونَ وَرَبِّ الْكَعْبَةِ، هُمُ الأَخْسَرُونَ وَرَبِّ الْكَعْبَةِ ‏"‏ قُلْتُ مَا شَأْنِي أَيُرَى فِيَّ شَىْءٌ مَا شَأْنِي فَجَلَسْتُ إِلَيْهِ وَهْوَ يَقُولُ، فَمَا اسْتَطَعْتُ أَنْ أَسْكُتَ، وَتَغَشَّانِي مَا شَاءَ اللَّهُ، فَقُلْتُ مَنْ هُمْ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الأَكْثَرُونَ أَمْوَالاً، إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏\hadithno{6638}\hadithtrans{Narrated Abu Dhar:I reached him (the Prophet (ﷺ) ) while in the shade of the Ka`ba; he was saying, "They are the losers, by the Lord of the Ka`ba! They are the losers, by the Lord of the Ka`ba!" I said (to myself ), "What is wrong with me? Is anything improper detected in me? What is wrong with me? Then I sat beside him and he kept on saying his statement. I could not remain quiet, and Allah knows in what sorrowful state I was at that time. So I said, ' Who are they (the losers)? Let My father and mother be sacrificed for you, O Allah's Messenger (ﷺ)!" He said, "They are the wealthy people, except the one who does like this and like this and like this (i.e., spends of his wealth in Allah's Cause)}}
\hadithdefcmd{bukhari}{6639}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ سُلَيْمَانُ لأَطُوفَنَّ اللَّيْلَةَ عَلَى تِسْعِينَ امْرَأَةً، كُلُّهُنَّ تَأْتِي بِفَارِسٍ يُجَاهِدُ فِي سَبِيلِ اللَّهِ‏.‏ فَقَالَ لَهُ صَاحِبُهُ إِنْ شَاءَ اللَّهُ‏.‏ فَلَمْ يَقُلْ إِنْ شَاءَ اللَّهُ‏.‏ فَطَافَ عَلَيْهِنَّ جَمِيعًا، فَلَمْ تَحْمِلْ مِنْهُنَّ إِلاَّ امْرَأَةٌ وَاحِدَةٌ، جَاءَتْ بِشِقِّ رَجُلٍ، وَايْمُ الَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ قَالَ إِنْ شَاءَ اللَّهُ‏.‏ لَجَاهَدُوا فِي سَبِيلِ اللَّهِ فُرْسَانًا أَجْمَعُونَ ‏"‏‏.‏\hadithno{6639}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "(The Prophet) Solomon once said, 'Tonight I will sleep with ninety women, each of whom will bring forth a (would-be) cavalier who will fight in Allah's Cause." On this, his companion said to him, "Say: Allah willing!" But he did not say Allah willing. Solomon then slept with all the women, but none of them became pregnant but one woman who later delivered a halfman. By Him in Whose Hand Muhammad's soul is, if he (Solomon) had said, 'Allah willing' (all his wives would have brought forth boys) and they would have fought in Allah's Cause as cavaliers}}
\hadithdefcmd{bukhari}{6640}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أُهْدِيَ إِلَى النَّبِيِّ صلى الله عليه وسلم سَرَقَةٌ مِنْ حَرِيرٍ، فَجَعَلَ النَّاسُ يَتَدَاوَلُونَهَا بَيْنَهُمْ، وَيَعْجَبُونَ مِنْ حُسْنِهَا وَلِينِهَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَعْجَبُونَ مِنْهَا ‏"‏‏.‏ قَالُوا نَعَمْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَمَنَادِيلُ سَعْدٍ فِي الْجَنَّةِ خَيْرٌ مِنْهَا ‏"‏‏.‏ لَمْ يَقُلْ شُعْبَةُ وَإِسْرَائِيلُ عَنْ أَبِي إِسْحَاقَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ ‏"‏‏.‏\hadithno{6640}\hadithtrans{Narrated Al-Bara 'bin `Azib:A piece of silken cloth was given to the Prophet (ﷺ) as a present and the people handed it over amongst themselves and were astonished at its beauty and softness. Allah's Messenger (ﷺ) said, "Are you astonished at it?" They said, "Yes, O Allah's Messenger (ﷺ)!" He said, "By Him in Whose Hand my soul is, the handkerchiefs of Sa`d in Paradise are better than it}}
\hadithdefcmd{bukhari}{6641}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ إِنَّ هِنْدَ بِنْتَ عُتْبَةَ بْنِ رَبِيعَةَ قَالَتْ يَا رَسُولَ اللَّهِ مَا كَانَ مِمَّا عَلَى ظَهْرِ الأَرْضِ أَهْلُ أَخْبَاءٍ ـ أَوْ خِبَاءٍ ـ أَحَبَّ إِلَىَّ أَنْ يَذِلُّوا مِنْ أَهْلِ أَخْبَائِكَ ـ أَوْ خِبَائِكَ، شَكَّ يَحْيَى ـ ثُمَّ مَا أَصْبَحَ الْيَوْمَ أَهْلُ أَخْبَاءٍ ـ أَوْ خِبَاءٍ ـ أَحَبَّ إِلَىَّ مِنْ أَنْ يَعِزُّوا مِنْ أَهْلِ أَخْبَائِكَ أَوْ خِبَائِكَ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَيْضًا وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ ‏"‏‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مِسِّيكٌ، فَهَلْ عَلَىَّ حَرَجٌ أَنْ أُطْعِمَ مِنَ الَّذِي لَهُ قَالَ ‏"‏ لاَ إِلاَّ بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{6641}\hadithtrans{Narrated `Aisha:Hind bint `Utba bin Rabi`a said, "O Allah's Apostle! (Before I embraced Islam), there was no family on the surface of the earth, I wish to have degraded more than I did your family. But today there is no family whom I wish to have honored more than I did yours." Allah's Messenger (ﷺ) said, "I thought similarly, by Him in Whose Hand Muhammad's soul is!" Hind said, "O Allah's Messenger (ﷺ)! (My husband) Abu Sufyan is a miser. Is it sinful of me to feed my children from his property?" The Prophet said, "No, unless you take it for your needs what is just and reasonable}}
\hadithdefcmd{bukhari}{6642}{حَدَّثَنِي أَحْمَدُ بْنُ عُثْمَانَ، حَدَّثَنَا شُرَيْحُ بْنُ مَسْلَمَةَ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، سَمِعْتُ عَمْرَو بْنَ مَيْمُونٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُضِيفٌ ظَهْرَهُ إِلَى قُبَّةٍ مِنْ أَدَمٍ يَمَانٍ إِذْ قَالَ لأَصْحَابِهِ ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا رُبُعَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ قَالُوا بَلَى‏.‏ قَالَ ‏"‏ أَفَلَمْ تَرْضَوْا أَنْ تَكُونُوا ثُلُثَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ قَالُوا بَلَى‏.‏ قَالَ ‏"‏ فَوَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ، إِنِّي لأَرْجُو أَنْ تَكُونُوا نِصْفَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏\hadithno{6642}\hadithtrans{Narrated `Abdullah bin Masud:While Allah's Messenger (ﷺ) was sitting, reclining his back against a Yemenite leather tent he said to his companions, "Will you be pleased to be one-fourth of the people of Paradise?" They said, 'Yes.' He said "Won't you be pleased to be one-third of the people of Paradise" They said, "Yes." He said, "By Him in Whose Hand Muhammad's soul is, I hope that you will be one-half of the people of Paradise}}
\hadithdefcmd{bukhari}{6643}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَجُلاً، سَمِعَ رَجُلاً، يَقْرَأُ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ يُرَدِّدُهَا، فَلَمَّا أَصْبَحَ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ، وَكَأَنَّ الرَّجُلَ يَتَقَالُّهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهَا لَتَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏‏.‏\hadithno{6643}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A man heard another man reciting: Surat-ul-Ikhlas (The Unity) 'Say: He is Allah, the One (112) and he was repeating it. The next morning he came to Allah's Messenger (ﷺ) and mentioned the whole story to him as if he regarded the recitation of that Sura as insufficient On that, Allah's Messenger (ﷺ) said, "By Him in Whose Hand my soul is! That (Sura No. 112) equals one-third of the Qur'an}}
\hadithdefcmd{bukhari}{6644}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَتِمُّوا الرُّكُوعَ وَالسُّجُودَ، فَوَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَرَاكُمْ مِنْ بَعْدِ ظَهْرِي إِذَا مَا رَكَعْتُمْ وَإِذَا مَا سَجَدْتُمْ ‏"‏‏.‏\hadithno{6644}\hadithtrans{Narrated Anas bin Malik:I heard the Prophet (ﷺ) saying, "Perform the bowing and the prostration properly (with peace of mind), for, by Him in Whose Hand my soul is, I see you from behind my back when you bow and when you prostrate}}
\hadithdefcmd{bukhari}{6645}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ امْرَأَةً، مِنَ الأَنْصَارِ أَتَتِ النَّبِيَّ صلى الله عليه وسلم مَعَهَا أَوْلاَدٌ لَهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّكُمْ لأَحَبُّ النَّاسِ إِلَىَّ ‏"‏‏.‏ قَالَهَا ثَلاَثَ مِرَارٍ‏.‏\hadithno{6645}\hadithtrans{Narrated Anas bin Malik:An Ansari woman came to the Prophet (ﷺ) in the company of her children, and the Prophet (ﷺ) said to her, "By Him in Whose Hand my soul is, you are the most beloved people to me!" And he repeated the statement thrice}}
\hadithdefcmd{bukhari}{6646}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَدْرَكَ عُمَرَ بْنَ الْخَطَّابِ وَهْوَ يَسِيرُ فِي رَكْبٍ يَحْلِفُ بِأَبِيهِ فَقَالَ ‏ "‏ أَلاَ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ، مَنْ كَانَ حَالِفًا فَلْيَحْلِفْ بِاللَّهِ، أَوْ لِيَصْمُتْ ‏"‏‏.‏\hadithno{6646}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) met `Umar bin Al-Khattab while the latter was going with a group of camel-riders, and he was swearing by his father. The Prophet (ﷺ) said, "Lo! Allah forbids you to swear by your fathers, so whoever has to take an oath, he should swear by Allah or keep quiet}}
\hadithdefcmd{bukhari}{6647}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ سَالِمٌ قَالَ ابْنُ عُمَرَ سَمِعْتُ عُمَرَ، يَقُولُ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا حَلَفْتُ بِهَا مُنْذُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم ذَاكِرًا وَلاَ آثِرًا‏.‏ قَالَ مُجَاهِدٌ ‏\{‏أَوْ أَثَرَةٍ مِنْ عِلْمٍ‏\}‏ يَأْثُرُ عِلْمًا‏.‏ تَابَعَهُ عُقَيْلٌ وَالزُّبَيْدِيُّ وَإِسْحَاقُ الْكَلْبِيُّ عَنِ الزُّهْرِيِّ‏.‏ وَقَالَ ابْنُ عُيَيْنَةَ وَمَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ سَمِعَ النَّبِيُّ صلى الله عليه وسلم عُمَرَ‏.‏\hadithno{6647}\hadithtrans{Narrated Ibn `Umar:I heard `Umar saying, "Allah's Messenger (ﷺ) said to me, 'Allah forbids you to swear by your fathers." `Umar said, "By Allah! Since I heard that from the Prophet (ﷺ) , I have not taken such an oath, neither intentionally, nor by reporting the oath of someone else}}
\hadithdefcmd{bukhari}{6648}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهُ صلى الله عليه وسلم ‏ "‏ لاَ تَحْلِفُوا بِآبَائِكُمْ ‏"‏‏.‏\hadithno{6648}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Do not swear by your fathers}}
\hadithdefcmd{bukhari}{6649}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، وَالْقَاسِمِ التَّمِيمِيِّ، عَنْ زَهْدَمٍ، قَالَ كَانَ بَيْنَ هَذَا الْحَىِّ مِنْ جَرْمٍ وَبَيْنَ الأَشْعَرِيِّينَ وُدٌّ وَإِخَاءٌ، فَكُنَّا عِنْدَ أَبِي مُوسَى الأَشْعَرِيِّ، فَقُرِّبَ إِلَيْهِ طَعَامٌ فِيهِ لَحْمُ دَجَاجٍ وَعِنْدَهُ رَجُلٌ مِنْ بَنِي تَيْمِ اللَّهِ أَحْمَرُ كَأَنَّهُ مِنَ الْمَوَالِي، فَدَعَاهُ إِلَى الطَّعَامِ فَقَالَ إِنِّي رَأَيْتُهُ يَأْكُلُ شَيْئًا فَقَذِرْتُهُ، فَحَلَفْتُ أَنْ لاَ آكُلَهُ‏.‏ فَقَالَ قُمْ فَلأُحَدِّثَنَّكَ عَنْ ذَاكَ، إِنِّي أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَفَرٍ مِنَ الأَشْعَرِيِّينَ نَسْتَحْمِلُهُ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ، وَمَا عِنْدِي مَا أَحْمِلُكُمْ ‏"‏‏.‏ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَهْبِ إِبِلٍ فَسَأَلَ عَنَّا‏.‏ فَقَالَ ‏"‏ أَيْنَ النَّفَرُ الأَشْعَرِيُّونَ ‏"‏‏.‏ فَأَمَرَ لَنَا بِخَمْسِ ذَوْدٍ غُرِّ الذُّرَى، فَلَمَّا انْطَلَقْنَا قُلْنَا مَا صَنَعْنَا حَلَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَحْمِلُنَا وَمَا عِنْدَهُ مَا يَحْمِلُنَا ثُمَّ حَمَلَنَا، تَغَفَّلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَمِينَهُ، وَاللَّهِ لاَ نُفْلِحُ أَبَدًا، فَرَجَعْنَا إِلَيْهِ فَقُلْنَا لَهُ إِنَّا أَتَيْنَاكَ لِتَحْمِلَنَا فَحَلَفْتَ أَنْ لاَ تَحْمِلَنَا، وَمَا عِنْدَكَ مَا تَحْمِلُنَا‏.‏ فَقَالَ ‏"‏ إِنِّي لَسْتُ أَنَا حَمَلْتُكُمْ، وَلَكِنَّ اللَّهَ حَمَلَكُمْ، وَاللَّهِ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ وَتَحَلَّلْتُهَا ‏"‏‏.‏\hadithno{6649}\hadithtrans{Narrated Zahdam:There was a relation of love and brotherhood between this tribe of Jarm and Al-Ash`ariyin. Once we were with Abu Musa Al-Ash`ari, and then a meal containing chicken was brought to Abu Musa, and there was present, a man from the tribe of Taimillah who was of red complexion as if he were from non-Arab freed slaves. Abu Musa invited him to the meal. He said, "I have seen chickens eating dirty things, so I deemed it filthy and took an oath that I would never eat chicken." On that, Abu Musa said, "Get up, I will narrate to you about that. Once a group of the Ash`ariyin and I went to Allah's Messenger (ﷺ) and asked him to provide us with mounts; he said, 'By Allah, I will never give you any mounts nor do I have anything to mount you on.' Then a few camels of war booty were brought to Allah's Messenger (ﷺ) , and he asked about us, saying, 'Where are the Ash-'ariyin?' He then ordered five nice camels to be given to us, and when we had departed, we said, 'What have we done? Allah's Messenger (ﷺ) had taken the oath not to give us any mounts, and that he had nothing to mount us on, and later he gave us that we might ride? Did we take advantage of the fact that Allah's Messenger (ﷺ) had forgotten his oath? By Allah, we will never succeed.' So we went back to him and said to him, 'We came to you to give us mounts, and you took an oath that you would not give us any mounts and that you had nothing to mount us on.' On that he said, 'I did not provide you with mounts, but Allah did. By Allah, if I take an oath to do something, and then find something else better than it, I do that which is better and make expiation for the dissolution of the oath}}
\hadithdefcmd{bukhari}{6650}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ فَقَالَ فِي حَلِفِهِ بِاللاَّتِ وَالْعُزَّى‏.‏ فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ وَمَنْ قَالَ لِصَاحِبِهِ تَعَالَ أُقَامِرْكَ‏.‏ فَلْيَتَصَدَّقْ ‏"‏‏.‏\hadithno{6650}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever swears saying in his oath. 'By Al-Lat and Al-`Uzza,' should say, 'None has the right to be worshipped but Allah; and whoever says to his friend, 'Come, let me gamble with you,' should give something in charity}}
\hadithdefcmd{bukhari}{6651}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اصْطَنَعَ خَاتَمًا مِنْ ذَهَبٍ وَكَانَ يَلْبَسُهُ، فَيَجْعَلُ فَصَّهُ فِي بَاطِنِ كَفِّهِ، فَصَنَعَ النَّاسُ خَوَاتِيمَ ثُمَّ إِنَّهُ جَلَسَ عَلَى الْمِنْبَرِ فَنَزَعَهُ، فَقَالَ ‏"‏ إِنِّي كُنْتُ أَلْبَسُ هَذَا الْخَاتِمَ وَأَجْعَلُ فَصَّهُ مِنْ دَاخِلٍ ‏"‏‏.‏ فَرَمَى بِهِ ثُمَّ قَالَ ‏"‏ وَاللَّهِ لاَ أَلْبَسُهُ أَبَدًا ‏"‏‏.‏ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ‏.‏\hadithno{6651}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) had a gold ring made for himself, and he used to wear it with the stone towards the inner part of his hand. Consequently, the people had similar rings made for themselves. Afterwards the Prophet; sat on the pulpit and took it off, saying, "I used to wear this ring and keep its stone towards the palm of my hand." He then threw it away and said, "By Allah, I will never wear it." Therefore all the people threw away their rings as well}}
\hadithdefcmd{bukhari}{6652}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ بِغَيْرِ مِلَّةِ الإِسْلاَمِ فَهْوَ كَمَا قَالَ ـ قَالَ ـ وَمَنْ قَتَلَ نَفْسَهُ بِشَىْءٍ عُذِّبَ بِهِ فِي نَارِ جَهَنَّمَ، وَلَعْنُ الْمُؤْمِنِ كَقَتْلِهِ، وَمَنْ رَمَى مُؤْمِنًا بِكُفْرٍ فَهْوَ كَقَتْلِهِ ‏"‏‏.‏\hadithno{6652}\hadithtrans{Narrated Thabit bin Ad-Dahhak:The Prophet (ﷺ) said, "Whoever swears by a religion other than Islam, is, as he says; and whoever commits suicide with something, will be punished with the same thing in the (Hell) Fire; and cursing a believer is like murdering him; and whoever accuses a believer of disbelief, then it is as if he had killed him}}
\hadithdefcmd{bukhari}{6653}{وَقَالَ عَمْرُو بْنُ عَاصِمٍ حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُ أَنَّهُ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ ثَلاَثَةً فِي بَنِي إِسْرَائِيلَ أَرَادَ اللَّهُ أَنْ يَبْتَلِيَهُمْ، فَبَعَثَ مَلَكًا فَأَتَى الأَبْرَصَ فَقَالَ تَقَطَّعَتْ بِي الْحِبَالُ، فَلاَ بَلاَغَ لِي إِلاَّ بِاللَّهِ، ثُمَّ بِكَ ‏"‏‏.‏ فَذَكَرَ الْحَدِيثَ‏.‏\hadithno{6653}\hadithtrans{Narrated Abu Hurairah that he heard the Prophet (ﷺ) saying, "Allah decided to test three people from Bani Isra'il. So, He sent an angel who came first to the leper and said, '(I am a traveller) who has run short of all means of living, and I have nobody to help me except Allah, and then with your help.'" Abu Hurairah then mentioned the complete narration}}
\hadithdefcmd{bukhari}{6654}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ أَشْعَثَ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَشْعَثَ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم بِإِبْرَارِ الْمُقْسِمِ‏.‏\hadithno{6654}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) ordered us to help others to fulfill the oaths}}
\hadithdefcmd{bukhari}{6655}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا عَاصِمٌ الأَحْوَلُ، سَمِعْتُ أَبَا عُثْمَانَ، يُحَدِّثُ عَنْ أُسَامَةَ، أَنَّ ابْنَةً لِرَسُولِ اللَّهِ، صلى الله عليه وسلم أَرْسَلَتْ إِلَيْهِ وَمَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أُسَامَةُ بْنُ زَيْدٍ وَسَعْدٌ وَأُبَىٌّ أَنَّ ابْنِي قَدِ احْتُضِرَ فَاشْهَدْنَا‏.‏ فَأَرْسَلَ يَقْرَأُ السَّلاَمَ وَيَقُولُ ‏"‏ إِنَّ لِلَّهِ مَا أَخَذَ وَمَا أَعْطَى وَكُلُّ شَىْءٍ عِنْدَهُ مُسَمًّى فَلْتَصْبِرْ وَتَحْتَسِبْ ‏"‏‏.‏ فَأَرْسَلَتْ إِلَيْهِ تُقْسِمُ عَلَيْهِ، فَقَامَ وَقُمْنَا مَعَهُ، فَلَمَّا قَعَدَ رُفِعَ إِلَيْهِ، فَأَقْعَدَهُ فِي حَجْرِهِ وَنَفْسُ الصَّبِيِّ تَقَعْقَعُ، فَفَاضَتْ عَيْنَا رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ سَعْدٌ مَا هَذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هَذَا رَحْمَةٌ يَضَعُهَا اللَّهُ فِي قُلُوبِ مَنْ يَشَاءُ مِنْ عِبَادِهِ، وَإِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏‏.‏\hadithno{6655}\hadithtrans{Narrated Usama:Once a daughter of Allah's Messenger (ﷺ) sent a message to Allah's Messenger (ﷺ) while Usama, Sa`d, and my father or Ubai were (sitting there) with him. She said, (in the message); My child is going to die; please come to us." Allah's Messenger (ﷺ) returned the messenger and told him to convey his greetings to her, and say, "Whatever Allah takes, is for Him and whatever He gives is for Him, and everything with Him has a limited fixed term (in this world): so she should be patient and hope for Allah's reward." Then she again sent for him swearing that he should come; so The Prophet (ﷺ) got up, and so did we. When he sat there (at the house of his daughter), the child was brought to him, and he took him into his lap while the child's breath was disturbed in his chest. The eyes of Allah's Messenger (ﷺ) started shedding tears. Sa`d said, "What is this, O Allah's Messenger (ﷺ)?" The Prophet (ﷺ) said, "This is the mercy which Allah has lodged in the hearts of whoever He wants of His slaves, and verily Allah is merciful only to those of His slaves who are merciful (to others)}}
\hadithdefcmd{bukhari}{6656}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمُوتُ لأَحَدٍ مِنَ الْمُسْلِمِينَ ثَلاَثَةٌ مِنَ الْوَلَدِ، تَمَسُّهُ النَّارُ، إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏‏.‏\hadithno{6656}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Any Muslim who has lost three of his children will not be touched by the Fire except that which will render Allah's oath fulfilled}}
\hadithdefcmd{bukhari}{6657}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَلاَ أَدُلُّكُمْ عَلَى أَهْلِ الْجَنَّةِ، كُلُّ ضَعِيفٍ مُتَضَعَّفٍ، لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ، وَأَهْلِ النَّارِ كُلُّ جَوَّاظٍ عُتُلٍّ مُسْتَكْبِرٍ ‏"‏‏.‏\hadithno{6657}\hadithtrans{Narrated Haritha bin Wahb:I heard the Prophet (ﷺ) saying, "Shall I tell you of the people of Paradise? They comprise every poor humble person, and if he swears by Allah to do something, Allah will fulfill it; while the people of the fire comprise every violent, cruel arrogant person}}
\hadithdefcmd{bukhari}{6658}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم أَىُّ النَّاسِ خَيْرٌ قَالَ ‏ "‏ قَرْنِي، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ يَجِيءُ قَوْمٌ تَسْبِقُ شَهَادَةُ أَحَدِهِمْ يَمِينَهُ، وَيَمِينُهُ شَهَادَتَهُ ‏"‏‏.‏ قَالَ إِبْرَاهِيمُ وَكَانَ أَصْحَابُنَا يَنْهَوْنَا وَنَحْنُ غِلْمَانٌ أَنْ نَحْلِفَ بِالشَّهَادَةِ وَالْعَهْدِ‏.‏\hadithno{6658}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) was asked, "Who are the best people?" He replied: The people of my generation, and then those who will follow (come after) them, and then those who will come after the later; after that there will come some people whose witness will precede their oaths and their oaths will go ahead of their witness." Ibrahim (a sub-narrator) said, "When we were young, our elder friends used to prohibit us from taking oaths by saying, 'I bear witness swearing by Allah, or by Allah's Covenant}}
\hadithdefcmd{bukhari}{6660}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، وَمَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ كَاذِبَةٍ، لِيَقْتَطِعَ بِهَا مَالَ رَجُلٍ مُسْلِمٍ أَوْ قَالَ أَخِيهِ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَهُ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ‏\}‏ قَالَ سُلَيْمَانُ فِي حَدِيثِهِ فَمَرَّ الأَشْعَثُ بْنُ قَيْسٍ فَقَالَ مَا يُحَدِّثُكُمْ عَبْدُ اللَّهِ قَالُوا لَهُ فَقَالَ الأَشْعَثُ نَزَلَتْ فِيَّ، وَفِي صَاحِبٍ لِي، فِي بِئْرٍ كَانَتْ بَيْنَنَا‏.‏\hadithno{6660}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Whoever swears falsely in order to grab the property of a Muslim (or of his brother), Allah will be angry with him when he meets Him." Allah then revealed in confirmation of the above statement:--'Verily those who purchase a small gain at the cost of Allah's Covenant and their own oaths.' (3.77) Al-Ash'ath said, "This Verse was revealed regarding me and a companion of mine when we had a dispute about a well}}
\hadithdefcmd{bukhari}{6661}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شَيْبَانُ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَزَالُ جَهَنَّمُ تَقُولُ هَلْ مِنْ مَزِيدٍ حَتَّى يَضَعَ رَبُّ الْعِزَّةِ فِيهَا قَدَمَهُ فَتَقُولُ قَطْ قَطْ وَعِزَّتِكَ‏.‏ وَيُزْوَى بَعْضُهَا إِلَى بَعْضٍ ‏"‏‏.‏ رَوَاهُ شُعْبَةُ عَنْ قَتَادَةَ‏.‏\hadithno{6661}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "The Hell Fire will keep on saying: 'Are there anymore (people to come)?' Till the Lord of Power and Honor will put His Foot over it and then it will say, 'Qat! Qat! (sufficient! sufficient!) by Your Power and Honor. And its various sides will come close to each other (i.e., it will contract)}}
\hadithdefcmd{bukhari}{6662}{حَدَّثَنَا الأُوَيْسِيُّ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، ح وَحَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ النُّمَيْرِيُّ، حَدَّثَنَا يُونُسُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، قَالَ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، وَسَعِيدَ بْنَ الْمُسَيَّبِ، وَعَلْقَمَةَ بْنَ وَقَّاصٍ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، عَنْ حَدِيثِ، عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا، فَبَرَّأَهَا اللَّهُ، وَكُلٌّ حَدَّثَنِي طَائِفَةً مِنَ الْحَدِيثِ ـ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَاسْتَعْذَرَ مِنْ عَبْدِ اللَّهِ بْنِ أُبَىٍّ، فَقَامَ أُسَيْدُ بْنُ حُضَيْرٍ فَقَالَ لِسَعْدِ بْنِ عُبَادَةَ لَعَمْرُ اللَّهِ لَنَقْتُلَنَّهُ‏.‏\hadithno{6662}\hadithtrans{Narrated Az-Zuhri:I heard `Urwa bin Az-Zubair, Sa`id bin Al-Musaiyab, 'Alqama bin Waqqas and 'Ubaidullah bin `Abdullah narrating from `Aisha, the wife of the Prophet, the story about the liars who said what they said about her and how Allah revealed her innocence afterwards. Each one of the above four narrators narrated to me a portion of her narration. (It was said in it), "The Prophet (ﷺ) stood up, saying, 'Is there anyone who can relieve me from `Abdullah bin Ubai?' On that, Usaid bin Hudair got up and said to Sa`d bin 'Ubada, La`Amrullahi (By the Eternity of Allah), we will kill him}}
\hadithdefcmd{bukhari}{6663}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ‏\{‏لاَ يُؤَاخِذُكُمُ اللَّهُ بِاللَّغْوِ‏\}‏ قَالَ قَالَتْ أُنْزِلَتْ فِي قَوْلِهِ لاَ، وَاللَّهِ بَلَى وَاللَّهِ‏.‏\hadithno{6663}\hadithtrans{Narrated `Aisha:regarding: 'Allah will not call you to account for that which is unintentional in your oaths...' (2.225) This Verse was revealed concerning such oath formulas as: 'No, by Allah!' and 'Yes, by Allah!' something against his oath due to forgetfulness should he make expiation?). And the Statement of Allah: 'And there is no blame on you if you make a mistake therein.' (33.5) And Allah said:-- '(Moses said to Khadir): Call me not to account for what I forgot}}
\hadithdefcmd{bukhari}{6664}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا مِسْعَرٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا زُرَارَةُ بْنُ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، يَرْفَعُهُ قَالَ ‏ "‏ إِنَّ اللَّهَ تَجَاوَزَ لأُمَّتِي عَمَّا وَسْوَسَتْ أَوْ حَدَّثَتْ بِهِ أَنْفُسَهَا، مَا لَمْ تَعْمَلْ بِهِ أَوْ تَكَلَّمْ ‏"‏‏.‏\hadithno{6664}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah forgives my followers those (evil deeds) their souls may whisper or suggest to them as long as they do not act (on it) or speak}}
\hadithdefcmd{bukhari}{6665}{حَدَّثَنَا عُثْمَانُ بْنُ الْهَيْثَمِ، أَوْ مُحَمَّدٌ عَنْهُ عَنِ ابْنِ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ شِهَابٍ، يَقُولُ حَدَّثَنِي عِيسَى بْنُ طَلْحَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَيْنَمَا هُوَ يَخْطُبُ يَوْمَ النَّحْرِ إِذْ قَامَ إِلَيْهِ رَجُلٌ فَقَالَ كُنْتُ أَحْسِبُ يَا رَسُولَ اللَّهِ كَذَا وَكَذَا قَبْلَ كَذَا وَكَذَا‏.‏ ثُمَّ قَامَ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ كُنْتُ أَحْسِبُ كَذَا وَكَذَا لِهَؤُلاَءِ الثَّلاَثِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ افْعَلْ وَلاَ حَرَجَ ‏"‏ لَهُنَّ كُلِّهِنَّ يَوْمَئِذٍ، فَمَا سُئِلَ يَوْمَئِذٍ عَنْ شَىْءٍ إِلاَّ قَالَ ‏"‏ افْعَلْ وَلاَ حَرَجَ ‏"‏‏.‏\hadithno{6665}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-As:While the Prophet (ﷺ) was delivering a sermon on the Day of Nahr (i.e., 10th Dhul-Hijja-Day of slaughtering the sacrifice), a man got up saying, "I thought, O Allah's Messenger (ﷺ), such-and-such a thing was to be done before such-and-such a thing." Another man got up, saying, "O Allah's Messenger (ﷺ)! As regards these three (acts of Hajj), thought so-and-so." The Prophet (ﷺ) said, "Do, and there is no harm," concerning all those matters on that day. And so, on that day, whatever question he was asked, he said, "Do it, do it, and there is no harm therein}}
\hadithdefcmd{bukhari}{6666}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَجُلٌ لِلنَّبِيِّ صلى الله عليه وسلم زُرْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏ قَالَ آخَرُ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏ قَالَ آخَرُ ذَبَحْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏\hadithno{6666}\hadithtrans{Narrated Ibn `Abbas:A man said to the Prophet (while he was delivering a sermon on the Day of Nahr), "I have performed the Tawaf round the Ka`ba before the Rami (throwing pebbles) at the Jamra." The Prophet (ﷺ) said, "There is no harm (therein)." Another man said, "I had my head shaved before slaughtering (the sacrifice)." The Prophet (ﷺ) said, "There is no harm." A third said, "I have slaughtered (the sacrifice) before the Rami (throwing pebbles) at the Jamra." The Prophet (ﷺ) said, "There is no harm}}
\hadithdefcmd{bukhari}{6667}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ يُصَلِّي وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي نَاحِيَةِ الْمَسْجِدِ، فَجَاءَ فَسَلَّمَ عَلَيْهِ فَقَالَ لَهُ ‏"‏ ارْجِعْ فَصَلِّ، فَإِنَّكَ لَمْ تُصَلِّ ‏"‏‏.‏ فَرَجَعَ فَصَلَّى، ثُمَّ سَلَّمَ فَقَالَ ‏"‏ وَعَلَيْكَ، ارْجِعْ فَصَلِّ، فَإِنَّكَ لَمْ تُصَلِّ ‏"‏‏.‏ قَالَ فِي الثَّالِثَةِ فَأَعْلِمْنِي‏.‏ قَالَ ‏"‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَأَسْبِغِ الْوُضُوءَ، ثُمَّ اسْتَقْبِلِ الْقِبْلَةَ فَكَبِّرْ، وَاقْرَأْ بِمَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ، ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا، ثُمَّ ارْفَعْ رَأْسَكَ حَتَّى تَعْتَدِلَ قَائِمًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ، سَاجِدًا ثُمَّ ارْفَعْ حَتَّى تَسْتَوِيَ وَتَطْمَئِنَّ جَالِسًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا، ثُمَّ ارْفَعْ حَتَّى تَسْتَوِيَ قَائِمًا، ثُمَّ افْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا ‏"‏‏.‏\hadithno{6667}\hadithtrans{Narrated Abu Huraira:A man entered the mosque and started praying while Allah's Messenger (ﷺ) was sitting somewhere in the mosque. Then (after finishing the prayer) the man came to the Prophet (ﷺ) and greeted him. The Prophet (ﷺ) said to him, "Go back and pray, for you have not prayed. The man went back, and having prayed, he came and greeted the Prophet. The Prophet (ﷺ) after returning his greetings said, "Go back and pray, for you did not pray." On the third time the man said, "(O Allah's Messenger (ﷺ)!) teach me (how to pray)." The Prophet said, "When you get up for the prayer, perform the ablution properly and then face the Qibla and say Takbir (Allahu Akbar), and then recite of what you know of the Qur'an, and then bow, and remain in this state till you feel at rest in bowing, and then raise your head and stand straight; and then prostrate till you feel at rest in prostration, and then sit up till you feel at rest while sitting; and then prostrate again till you feel at rest in prostration; and then get up and stand straight, and do all this in all your prayers}}
\hadithdefcmd{bukhari}{6668}{حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ هُزِمَ الْمُشْرِكُونَ يَوْمَ أُحُدٍ هَزِيمَةً تُعْرَفُ فِيهِمْ، فَصَرَخَ إِبْلِيسُ أَىْ عِبَادَ اللَّهِ أُخْرَاكُمْ، فَرَجَعَتْ أُولاَهُمْ فَاجْتَلَدَتْ هِيَ وَأُخْرَاهُمْ، فَنَظَرَ حُذَيْفَةُ بْنُ الْيَمَانِ فَإِذَا هُوَ بِأَبِيهِ فَقَالَ أَبِي أَبِي‏.‏ قَالَتْ فَوَاللَّهِ مَا انْحَجَزُوا حَتَّى قَتَلُوهُ، فَقَالَ حُذَيْفَةُ غَفَرَ اللَّهُ لَكُمْ‏.‏ قَالَ عُرْوَةُ فَوَاللَّهِ مَا زَالَتْ فِي حُذَيْفَةَ مِنْهَا بَقِيَّةٌ حَتَّى لَقِيَ اللَّهَ‏.‏\hadithno{6668}\hadithtrans{Narrated `Aisha:When the pagans were defeated during the (first stage) of the battle of Uhud, Satan shouted, "O Allah's slaves! Beware of what is behind you!" So the front files of the Muslims attacked their own back files. Hudhaifa bin Al-Yaman looked and on seeing his father he shouted: "My father! My father!" By Allah! The people did not stop till they killed his father. Hudhaifa then said, "May Allah forgive you." `Urwa (the sub-narrator) added, "Hudhaifa continued asking Allah forgiveness for the killers of his father till he met Allah (till he died)}}
\hadithdefcmd{bukhari}{6669}{حَدَّثَنِي يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنِي عَوْفٌ، عَنْ خِلاَسٍ، وَمُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ نَاسِيًا وَهْوَ صَائِمٌ فَلْيُتِمَّ صَوْمَهُ، فَإِنَّمَا أَطْعَمَهُ اللَّهُ وَسَقَاهُ ‏"‏‏.‏\hadithno{6669}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If somebody eats something forgetfully while he is fasting, then he should complete his fast, for Allah has made him eat and drink}}
\hadithdefcmd{bukhari}{6670}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ، قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم فَقَامَ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ قَبْلَ أَنْ يَجْلِسَ، فَمَضَى فِي صَلاَتِهِ، فَلَمَّا قَضَى صَلاَتَهُ انْتَظَرَ النَّاسُ تَسْلِيمَهُ، وَسَجَدَ قَبْلَ أَنْ يُسَلِّمَ، ثُمَّ رَفَعَ رَأْسَهُ، ثُمَّ كَبَّرَ وَسَجَدَ، ثُمَّ رَفَعَ رَأْسَهُ وَسَلَّمَ‏.‏\hadithno{6670}\hadithtrans{Narrated `Abdullah bin Buhaina:Once Allah's Messenger (ﷺ) led us in prayer, and after finishing the first two rak`at, got up (instead of sitting for at-Tahiyyat) and then carried on with the prayer. When he had finished his prayer, the people were waiting for him to say Taslim, but before saying Tasiim, he said Takbir and prostrated; then he raised his head, and saying Takbir, he prostrated (SAHU) and then raised his head and finished his prayer with Taslim}}
\hadithdefcmd{bukhari}{6671}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ عَبْدَ الْعَزِيزِ بْنَ عَبْدِ الصَّمَدِ، حَدَّثَنَا مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم صَلَّى بِهِمْ صَلاَةَ الظُّهْرِ، فَزَادَ أَوْ نَقَصَ مِنْهَا ـ قَالَ مَنْصُورٌ لاَ أَدْرِي إِبْرَاهِيمُ وَهِمَ أَمْ عَلْقَمَةُ ـ قَالَ قِيلَ يَا رَسُولَ اللَّهِ أَقَصُرَتِ الصَّلاَةُ أَمْ نَسِيتَ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏‏.‏ قَالُوا صَلَّيْتَ كَذَا وَكَذَا‏.‏ قَالَ فَسَجَدَ بِهِمْ سَجْدَتَيْنِ ثُمَّ قَالَ ‏"‏ هَاتَانِ السَّجْدَتَانِ لِمَنْ لاَ يَدْرِي، زَادَ فِي صَلاَتِهِ أَمْ نَقَصَ، فَيَتَحَرَّى الصَّوَابَ، فَيُتِمُّ مَا بَقِيَ، ثُمَّ يَسْجُدُ سَجْدَتَيْنِ ‏"‏‏.‏\hadithno{6671}\hadithtrans{Narrated Ibn Mas`ud:that Allah's Prophet led them in the Zuhr prayer and he offered either more or less rak`at, and it was said to him, "O Allah's Messenger (ﷺ) ! Has the prayer been reduced, or have you forgotten?" He asked, "What is that?" They said, "You have prayed so many rak`at." So he performed with them two more prostrations and said, "These two prostrations are to be performed by the person who does not know whether he has prayed more or less (rak`at) in which case he should seek to follow what is right. And then complete the rest (of the prayer) and perform two extra prostrations}}
\hadithdefcmd{bukhari}{6672}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، أَخْبَرَنِي سَعِيدُ بْنُ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ فَقَالَ حَدَّثَنَا أُبَىُّ بْنُ كَعْبٍ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏\{‏لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ وَلاَ تُرْهِقْنِي مِنْ أَمْرِي عُسْرًا‏\}‏ قَالَ ‏"‏ كَانَتِ الأُولَى مِنْ مُوسَى نِسْيَانًا ‏"‏‏.‏\hadithno{6672}\hadithtrans{Narrated Ubai bin Ka'b: that he heard Allah's Messenger (ﷺ) saying, "(Moses) said, 'Call me not to account for what I forget and be not hard upon me for my affair (with you)' (18.73) the first excuse of Moses was his forgetfulness}}
\hadithdefcmd{bukhari}{6673}{قَالَ أَبُو عَبْدِ اللَّهِ كَتَبَ إِلَىَّ مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الشَّعْبِيِّ، قَالَ قَالَ الْبَرَاءُ بْنُ عَازِبٍ وَكَانَ عِنْدَهُمْ ضَيْفٌ لَهُمْ فَأَمَرَ أَهْلَهُ أَنْ يَذْبَحُوا قَبْلَ أَنْ يَرْجِعَ، لِيَأْكُلَ ضَيْفُهُمْ، فَذَبَحُوا قَبْلَ الصَّلاَةِ، فَذَكَرُوا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يُعِيدَ الذَّبْحَ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ عِنْدِي عَنَاقٌ جَذَعٌ، عَنَاقُ لَبَنٍ هِيَ خَيْرٌ مِنْ شَاتَىْ لَحْمٍ‏.‏ فَكَانَ ابْنُ عَوْنٍ يَقِفُ فِي هَذَا الْمَكَانِ عَنْ حَدِيثِ الشَّعْبِيِّ، وَيُحَدِّثُ عَنْ مُحَمَّدِ بْنِ سِيرِينَ بِمِثْلِ هَذَا الْحَدِيثِ، وَيَقِفُ فِي هَذَا الْمَكَانِ وَيَقُولُ لاَ أَدْرِي أَبَلَغَتِ الرُّخْصَةُ غَيْرَهُ أَمْ لاَ‏.‏ رَوَاهُ أَيُّوبُ عَنِ ابْنِ سِيرِينَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6673}\hadithtrans{Narrated Al-Bara bin Azib that once he had a guest, so he told his family (on the Day of Id-ul-Adha) that they should slaughter the animal for sacrifice before he returned from the ('Id) prayer in order that their guest could take his meal. So his family slaughtered (the animal ) before the prayer. Then they mentioned that event to the Prophet who ordered Al-Bara to slaughter another sacrifice. Al-Bara' said to the Prophet (ﷺ) , "I have a young milch she-goat which is better than two sheep for slaughtering." (The sub-narrator, Ibn 'Aun used to say, "I don't know whether the permission (to slaughter a she-goat as a sacrifice) was especially given to Al-Bara' or if it was in general for all the Muslims.") (See Hadith No. 99, Vol)}}
\hadithdefcmd{bukhari}{6674}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، قَالَ سَمِعْتُ جُنْدَبًا، قَالَ شَهِدْتُ النَّبِيَّ صلى الله عليه وسلم صَلَّى يَوْمَ عِيدٍ ثُمَّ خَطَبَ ثُمَّ قَالَ ‏ "‏ مَنْ ذَبَحَ فَلْيُبَدِّلْ مَكَانَهَا، وَمَنْ لَمْ يَكُنْ ذَبَحَ فَلْيَذْبَحْ بِاسْمِ اللَّهِ ‏"‏‏.‏\hadithno{6674}\hadithtrans{Narrated Jundub:I witnessed the Prophet (ﷺ) offering the `Id prayer (and after finishing it) he delivered a sermon and said, "Whoever has slaughtered his sacrifice (before the prayer) should make up for it (i.e. slaughter another animal) and whoever has not slaughtered his sacrifice yet, should slaughter it by mentioning Allah's Name over it}}
\hadithdefcmd{bukhari}{6675}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا النَّضْرُ، أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا فِرَاسٌ، قَالَ سَمِعْتُ الشَّعْبِيَّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْكَبَائِرُ الإِشْرَاكُ بِاللَّهِ، وَعُقُوقُ الْوَالِدَيْنِ، وَقَتْلُ النَّفْسِ، وَالْيَمِينُ الْغَمُوسُ ‏"‏‏.‏\hadithno{6675}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "The biggest sins are: To join others in worship with Allah; to be undutiful to one's parents; to kill somebody unlawfully; and to take an oath Al-Ghamus}}
\hadithdefcmd{bukhari}{6677}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينِ صَبْرٍ، يَقْتَطِعُ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏ فَدَخَلَ الأَشْعَثُ بْنُ قَيْسٍ فَقَالَ مَا حَدَّثَكُمْ أَبُو عَبْدِ الرَّحْمَنِ، فَقَالُوا كَذَا وَكَذَا‏.‏ قَالَ فِيَّ أُنْزِلَتْ، كَانَتْ لِي بِئْرٌ فِي أَرْضِ ابْنِ عَمٍّ لِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ بَيِّنَتُكَ أَوْ يَمِينُهُ ‏"‏‏.‏ قُلْتُ إِذًا يَحْلِفُ عَلَيْهَا يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينِ صَبْرٍ، وَهْوَ فِيهَا فَاجِرٌ، يَقْتَطِعُ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ يَوْمَ الْقِيَامَةِ، وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏\hadithno{6677}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "If somebody is ordered (by the ruler or the judge) to take an oath, and he takes a false oath in order to grab the property of a Muslim, then he will incur Allah's Wrath when he will meet Him." And Allah revealed in its confirmation: 'Verily! Those who purchase a small gain at the cost of Allah's covenants and their own oaths.' (3.77) (The sub-narrator added:) Al-Ash'ath bin Qais entered, saying, "What did Abu `Abdur-Rahman narrate to you?" They said, "So-and-so," Al-Ash'ath said, "This verse was revealed in my connection. I had a well on the land of my cousin (and we had a dispute about it). I reported him to Allah's Apostle who said (to me). "You should give evidence (i.e. witness) otherwise the oath of your opponent will render your claim invalid." I said, "Then he (my opponent) will take the oath, O Allah's Messenger (ﷺ)." Allah's Messenger (ﷺ) said, "Whoever is ordered (by the ruler or the judge) to give an oath, and he takes a false oath in order to grab the property of a Muslim, then he will incur Allah's Wrath when he meets Him on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6678}{حَدَّثَنِي مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ أَرْسَلَنِي أَصْحَابِي إِلَى النَّبِيِّ صلى الله عليه وسلم أَسْأَلُهُ الْحُمْلاَنَ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ عَلَى شَىْءٍ ‏"‏‏.‏ وَوَافَقْتُهُ وَهْوَ غَضْبَانُ فَلَمَّا أَتَيْتُهُ قَالَ ‏"‏ انْطَلِقْ إِلَى أَصْحَابِكَ فَقُلْ إِنَّ اللَّهَ ـ أَوْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ـ يَحْمِلُكُمْ ‏"‏‏.‏\hadithno{6678}\hadithtrans{Narrated Abu Musa:My companions sent me to the Prophet (ﷺ) to ask him for some mounts. He said, "By Allah! I will not mount you on anything!" When I met him, he was in an angry mood, but when I met him (again), he said, "Tell your companions that Allah or Allah's Messenger (ﷺ) will provide you with mounts}}
\hadithdefcmd{bukhari}{6679}{حَدَّثَنَا عَبْدُ الْعَزِيزِ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، ح وَحَدَّثَنَا الْحَجَّاجُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ النُّمَيْرِيُّ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ الأَيْلِيُّ، قَالَ سَمِعْتُ الزُّهْرِيَّ، قَالَ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، وَسَعِيدَ بْنَ الْمُسَيَّبِ، وَعَلْقَمَةَ بْنَ وَقَّاصٍ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ حَدِيثِ، عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا، فَبَرَّأَهَا اللَّهُ مِمَّا قَالُوا ـ كُلٌّ حَدَّثَنِي طَائِفَةً مِنَ الْحَدِيثِ ـ فَأَنْزَلَ اللَّهُ ‏\{‏إِنَّ الَّذِينَ جَاءُوا بِالإِفْكِ‏\}‏ الْعَشْرَ الآيَاتِ كُلَّهَا فِي بَرَاءَتِي‏.‏ فَقَالَ أَبُو بَكْرٍ الصِّدِّيقُ ـ وَكَانَ يُنْفِقُ عَلَى مِسْطَحٍ لِقَرَابَتِهِ مِنْهُ ـ وَاللَّهِ لاَ أُنْفِقُ عَلَى مِسْطَحٍ شَيْئًا أَبَدًا، بَعْدَ الَّذِي قَالَ لِعَائِشَةَ‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏وَلاَ يَأْتَلِ أُولُو الْفَضْلِ مِنْكُمْ وَالسَّعَةِ أَنْ يُؤْتُوا أُولِي الْقُرْبَى‏\}‏ الآيَةَ‏.‏ قَالَ أَبُو بَكْرٍ بَلَى وَاللَّهِ إِنِّي لأُحِبُّ أَنْ يَغْفِرَ اللَّهُ لِي‏.‏ فَرَجَعَ إِلَى مِسْطَحٍ النَّفَقَةَ الَّتِي كَانَ يُنْفِقُ عَلَيْهِ وَقَالَ وَاللَّهِ لاَ أَنْزِعُهَا عَنْهُ أَبَدًا‏.‏\hadithno{6679}\hadithtrans{Narrated Az-Zuhri:I heard `Urwa bin Az-Zubair, Sa`id bin Al-Musaiyab, 'Alqama bin Waqqas and 'Ubaidullah bin `Abdullah bin `Uqba relating from `Aisha, the wife of the Prophet (ﷺ) the narration of the people (i.e. the liars) who spread the slander against her and they said what they said, and how Allah revealed her innocence. Each of them related to me a portion of that narration. (They said that `Aisha said), ''Then Allah revealed the ten Verses starting with:--'Verily! Those who spread the slander..' (24.11-21) All these verses were in proof of my innocence. Abu Bakr As-Siddiq who used to provide for Mistah some financial aid because of his relation to him, said, "By Allah, I will never give anything (in charity) to Mistah, after what he has said about `Aisha" Then Allah revealed:-- 'And let not those among you who are good and are wealthy swear not to give (any sort of help) to their kins men....' (24.22) On that, Abu Bakr said, "Yes, by Allah, I like that Allah should forgive me." and then resumed giving Mistah the aid he used to give him and said, "By Allah! I will never withhold it from him}}
\hadithdefcmd{bukhari}{6680}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنِ الْقَاسِمِ، عَنْ زَهْدَمٍ، قَالَ كُنَّا عِنْدَ أَبِي مُوسَى الأَشْعَرِيِّ قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَفَرٍ مِنَ الأَشْعَرِيِّينَ، فَوَافَقْتُهُ وَهْوَ غَضْبَانُ فَاسْتَحْمَلْنَاهُ، فَحَلَفَ أَنْ لاَ يَحْمِلَنَا ثُمَّ قَالَ ‏ "‏ وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ وَتَحَلَّلْتُهَا ‏"‏‏.‏\hadithno{6680}\hadithtrans{Narrated Abu Musa Al-Ash`ari:I went along with some men from the Ash-ariyin to Allah's Messenger (ﷺ) and it happened that I met him while he was in an angry mood. We asked him to provide us with mounts, but he swore that he would not give us any. Later on he said, "By Allah, Allah willing, if ever I take an oath (to do something) and later on I find something else better than the first, then I do the better one and give expiation for the dissolution of my oath}}
\hadithdefcmd{bukhari}{6681}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِيهِ، قَالَ لَمَّا حَضَرَتْ أَبَا طَالِبٍ الْوَفَاةُ جَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ كَلِمَةً‏.‏ أُحَاجُّ لَكَ بِهَا عِنْدَ اللَّهِ ‏"‏‏.‏\hadithno{6681}\hadithtrans{Narrated Al-Musaiyab:When the death of Abu Talib approached, Allah's Messenger (ﷺ) came to him and said, "Say: La ilaha illallah, a word with which I will be able to defend you before Allah}}
\hadithdefcmd{bukhari}{6682}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَلِمَتَانِ خَفِيفَتَانِ عَلَى اللِّسَانِ، ثَقِيلَتَانِ فِي الْمِيزَانِ، حَبِيبَتَانِ إِلَى الرَّحْمَنِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ، سُبْحَانَ اللَّهِ الْعَظِيمِ ‏"‏‏.‏\hadithno{6682}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "(The following are) two words (sentences or utterances) that are very easy for the tongue to say, and very heavy in the balance (of reward), and most beloved to the Gracious Almighty (And they are): Subhan Allahi wa bi-hamdihi; Subhan Allahi-l-'Adhim}}
\hadithdefcmd{bukhari}{6683}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَلِمَةً وَقُلْتُ أُخْرَى ‏ "‏ مَنْ مَاتَ يَجْعَلُ لِلَّهِ نِدًّا أُدْخِلَ النَّارَ ‏"‏‏.‏ وَقُلْتُ أُخْرَى مَنْ مَاتَ لاَ يَجْعَلُ لِلَّهِ نِدًّا أُدْخِلَ الْجَنَّةَ‏.‏\hadithno{6683}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said a sentence and I said another. He said, "Whoever dies while he is setting up rivals along with Allah (i.e. worshipping others along with Allah) shall be admitted into the (Hell) Fire." And I said the other: "Whoever dies while he is not setting up rivals along with Allah (i.e. worshipping none except Allah) shall be admitted into Paradise}}
\hadithdefcmd{bukhari}{6684}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ آلَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نِسَائِهِ، وَكَانَتِ انْفَكَّتْ رِجْلُهُ، فَأَقَامَ فِي مَشْرُبَةٍ تِسْعًا وَعِشْرِينَ لَيْلَةً، ثُمَّ نَزَلَ فَقَالُوا يَا رَسُولَ اللَّهِ آلَيْتَ شَهْرًا‏.‏ فَقَالَ ‏\{‏إِنَّ الشَّهْرَ يَكُونُ تِسْعًا وَعِشْرِينَ‏\}‏\hadithno{6684}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) took an oath for abstention from his wives (for one month), and during those days he had a sprain in his foot. He stayed in a Mashrubah (an upper room) for twenty-nine nights and then came down. Then the people said, "O Allah's Messenger (ﷺ)! You took an oath for abstention (from your wives) for one month." On that he said, "A (lunar) month can be of twenty-nine days}}
\hadithdefcmd{bukhari}{6685}{حَدَّثَنِي عَلِيٌّ، سَمِعَ عَبْدَ الْعَزِيزِ بْنَ أَبِي حَازِمٍ، أَخْبَرَنِي أَبِي، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ أَبَا أُسَيْدٍ، صَاحِبَ النَّبِيِّ صلى الله عليه وسلم أَعْرَسَ فَدَعَا النَّبِيَّ صلى الله عليه وسلم لِعُرْسِهِ، فَكَانَتِ الْعَرُوسُ خَادِمَهُمْ‏.‏ فَقَالَ سَهْلٌ لِلْقَوْمِ هَلْ تَدْرُونَ مَا سَقَتْهُ قَالَ أَنْقَعَتْ لَهُ تَمْرًا فِي تَوْرٍ مِنَ اللَّيْلِ، حَتَّى أَصْبَحَ عَلَيْهِ فَسَقَتْهُ إِيَّاهُ‏.‏\hadithno{6685}\hadithtrans{Narrated Abu Hazim:Sahl bin Sa`d said, "Abu Usaid, the companion of the Prophet, got married, so he invited the Prophet (ﷺ) to his wedding party, and the bride herself served them. Sahl said to the People, 'Do you know what drink she served him with? She infused some dates in a pot at night and the next morning she served him with the infusion}}
\hadithdefcmd{bukhari}{6686}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنْ سَوْدَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ مَاتَتْ لَنَا شَاةٌ فَدَبَغْنَا مَسْكَهَا ثُمَّ مَا زِلْنَا نَنْبِذُ فِيهِ حَتَّى صَارَتْ شَنًّا‏.‏\hadithno{6686}\hadithtrans{Narrated Sauda:(the wife of the Prophet) One of our sheep died and we tanned its skin and kept on infusing dates in it till it was a worn out water skin}}
\hadithdefcmd{bukhari}{6687}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مِنْ خُبْزِ بُرٍّ مَأْدُومٍ ثَلاَثَةَ أَيَّامٍ حَتَّى لَحِقَ بِاللَّهِ‏.‏ وَقَالَ ابْنُ كَثِيرٍ أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِعَائِشَةَ بِهَذَا‏.‏\hadithno{6687}\hadithtrans{Narrated `Aisha:The family of (the Prophet) Muhammad never ate wheat-bread with meat for three consecutive days to their fill, till he met Allah}}
\hadithdefcmd{bukhari}{6688}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، قَالَ قَالَ أَبُو طَلْحَةَ لأُمِّ سُلَيْمٍ لَقَدْ سَمِعْتُ صَوْتَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ضَعِيفًا أَعْرِفُ فِيهِ الْجُوعَ، فَهَلْ عِنْدَكِ مِنْ شَىْءٍ فَقَالَتْ نَعَمْ‏.‏ فَأَخْرَجَتْ أَقْرَاصًا مِنْ شَعِيرٍ، ثُمَّ أَخَذَتْ خِمَارًا لَهَا، فَلَفَّتِ الْخُبْزَ بِبَعْضِهِ، ثُمَّ أَرْسَلَتْنِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَهَبْتُ فَوَجَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ وَمَعَهُ النَّاسُ، فَقُمْتُ عَلَيْهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسَلَكَ أَبُو طَلْحَةَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَنْ مَعَهُ ‏"‏ قُومُوا ‏"‏‏.‏ فَانْطَلَقُوا، وَانْطَلَقْتُ بَيْنَ أَيْدِيهِمْ حَتَّى جِئْتُ أَبَا طَلْحَةَ فَأَخْبَرْتُهُ‏.‏ فَقَالَ أَبُو طَلْحَةَ يَا أُمَّ سُلَيْمٍ قَدْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَيْسَ عِنْدَنَا مِنَ الطَّعَامِ مَا نُطْعِمُهُمْ‏.‏ فَقَالَتِ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَانْطَلَقَ أَبُو طَلْحَةَ حَتَّى لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو طَلْحَةَ حَتَّى دَخَلاَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلُمِّي يَا أُمَّ سُلَيْمٍ مَا عِنْدَكِ ‏"‏‏.‏ فَأَتَتْ بِذَلِكَ الْخُبْزِ ـ قَالَ ـ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَلِكَ الْخُبْزِ فَفُتَّ، وَعَصَرَتْ أُمُّ سُلَيْمٍ عُكَّةً لَهَا فَأَدَمَتْهُ، ثُمَّ قَالَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ أَنْ يَقُولَ، ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا، ثُمَّ خَرَجُوا، ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ، فَأَكَلَ الْقَوْمُ كُلُّهُمْ وَشَبِعُوا، وَالْقَوْمُ سَبْعُونَ أَوْ ثَمَانُونَ رَجُلاً‏.‏\hadithno{6688}\hadithtrans{Narrated Anas bin Malik:Abu Talha said to Um Sulaim, "I heard the voice of Allah's Messenger (ﷺ) rather weak, and I knew that it was because of hunger. Have you anything (to present to the Prophet)?" She said, "Yes." Then she took out a few loaves of barley bread and took a veil of hers and wrapped the bread with a part of it and sent me to Allah's Messenger (ﷺ). I went and found Allah's Messenger (ﷺ) sitting in the mosque with some people. I stood up before him. Allah's Messenger (ﷺ) said to me, "Has Abu Talha sent you?" I said, ' Yes. Then Allah's Messenger (ﷺ) said to those who were with him. "Get up and proceed." I went ahead of them (as their forerunner) and came to Abu Talha and informed him about it. Abu Talha said, "O Um Sulaim! Allah's Messenger (ﷺ) has come and we have no food to feed them." Um Sulaim said, "Allah and His Apostle know best." So Abu Talha went out (to receive them) till he met Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) came in company with Abu Talha and they entered the house. Allah's Messenger (ﷺ) said, "O Um Sulaim! Bring whatever you have." So she brought that (barley) bread and Allah's Messenger (ﷺ) ordered that bread to be broken into small pieces, and then Um Sulaim poured over it some butter from a leather butter container, and then Allah's Messenger (ﷺ) said what Allah wanted him to say, (i.e. blessing the food). Allah's Messenger (ﷺ) then said, "Admit ten men." Abu Talha admitted them and they ate to their fill and went out. He again said, "Admit ten men." He admitted them, and in this way all the people ate to their fill, and they were seventy or eighty men}}
\hadithdefcmd{bukhari}{6689}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، أَنَّهُ سَمِعَ عَلْقَمَةَ بْنَ وَقَّاصٍ اللَّيْثِيَّ، يَقُولُ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّةِ، وَإِنَّمَا لاِمْرِئٍ مَا نَوَى، فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ، وَمَنْ كَانَتْ هِجْرَتُهُ إِلَى دُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا، فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏‏.‏\hadithno{6689}\hadithtrans{Narrated `Umar bin Al-Khattab:I heard Allah's Messenger (ﷺ) saying, "The (reward of) deeds, depend upon the intentions and every person will get the reward according to what he has intended. So whoever emigrated for the sake of Allah and His Apostle, then his emigration will be considered to be for Allah and His Apostle, and whoever emigrated for the sake of worldly gain or for a woman to marry, then his emigration will be considered to be for what he emigrated for}}
\hadithdefcmd{bukhari}{6690}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، وَكَانَ، قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ ـ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، فِي حَدِيثِهِ ‏\{‏َعَلَى الثَّلاَثَةِ الَّذِينَ خُلِّفُوا‏\}‏ َقَالَ فِي آخِرِ حَدِيثِهِ إِنَّ مِنْ تَوْبَتِي أَنِّي أَنْخَلِعُ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَرَسُولِهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمْسِكْ عَلَيْكَ بَعْضَ مَالِكَ فَهْوَ خَيْرٌ لَكَ ‏"‏‏.‏\hadithno{6690}\hadithtrans{Narrated Ka`b bin Malik:In the last part of his narration about the three who remained behind (from the battle of Tabuk). (I said) "As a proof of my true repentance (for not joining the Holy battle of Tabuk), I shall give up all my property for the sake of Allah and His Apostle (as an expiation for that sin)." The Prophet (ﷺ) said (to me), "Keep some of your wealth, for that is better for you}}
\hadithdefcmd{bukhari}{6691}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الْحَجَّاجُ، عَنِ ابْنِ جُرَيْجٍ، قَالَ زَعَمَ عَطَاءٌ أَنَّهُ سَمِعَ عُبَيْدَ بْنَ عُمَيْرٍ، يَقُولُ سَمِعْتُ عَائِشَةَ، تَزْعُمُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمْكُثُ عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ، وَيَشْرَبُ عِنْدَهَا عَسَلاً، فَتَوَاصَيْتُ أَنَا وَحَفْصَةُ أَنَّ أَيَّتَنَا دَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَلْتَقُلْ إِنِّي أَجِدُ مِنْكَ رِيحَ مَغَافِيرَ، أَكَلْتَ مَغَافِيرَ فَدَخَلَ عَلَى إِحْدَاهُمَا فَقَالَتْ ذَلِكَ لَهُ‏.‏ فَقَالَ ‏"‏ لاَ بَلْ شَرِبْتُ عَسَلاً عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ، وَلَنْ أَعُودَ لَهُ ‏"‏‏.‏ فَنَزَلَتْ ‏\{‏يَا أَيُّهَا النَّبِيُّ لِمَ تُحَرِّمُ مَا أَحَلَّ اللَّهُ لَكَ‏\}‏، ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ‏\}‏، لِعَائِشَةَ وَحَفْصَةَ، ‏\{‏وَإِذْ أَسَرَّ النَّبِيُّ إِلَى بَعْضِ أَزْوَاجِهِ حَدِيثًا‏\}‏ لِقَوْلِهِ ‏"‏ بَلْ شَرِبْتُ عَسَلاً ‏"‏‏.‏ وَقَالَ لِي إِبْرَاهِيمُ بْنُ مُوسَى عَنْ هِشَامٍ، ‏"‏ وَلَنْ أَعُودَ لَهُ، وَقَدْ حَلَفْتُ، فَلاَ تُخْبِرِي بِذَلِكَ أَحَدًا ‏"‏‏.‏\hadithno{6691}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to stay (for a period) in the house of Zainab bint Jahsh (one of the wives of the Prophet ) and he used to drink honey in her house. Hafsa and I decided that when the Prophet (ﷺ) entered upon either of us, she would say, "I smell in you the bad smell of Maghafir (a bad smelling raisin). Have you eaten Maghafir?" When he entered upon one of us, she said that to him. He replied (to her), "No, but I have drunk honey in the house of Zainab bint Jahsh, and I will never drink it again." Then the following verse was revealed: 'O Prophet ! Why do you ban (for you) that which Allah has made lawful for you?. ..(up to) If you two (wives of the Prophet (ﷺ) turn in repentance to Allah.' (66.1-4) The two were `Aisha and Hafsa And also the Statement of Allah: 'And (Remember) when the Prophet (ﷺ) disclosed a matter in confidence to one of his wives!' (66.3) i.e., his saying, "But I have drunk honey." Hisham said: It also meant his saying, "I will not drink anymore, and I have taken an oath, so do not inform anybody of that}}
\hadithdefcmd{bukhari}{6692}{حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا سَعِيدُ بْنُ الْحَارِثِ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ أَوَلَمْ يُنْهَوْا عَنِ النَّذْرِ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ النَّذْرَ لاَ يُقَدِّمُ شَيْئًا، وَلاَ يُؤَخِّرُ، وَإِنَّمَا يُسْتَخْرَجُ بِالنَّذْرِ مِنَ الْبَخِيلِ ‏"‏‏.‏\hadithno{6692}\hadithtrans{Narrated Sa`id bin Al-Harith:that he heard Ibn `Umar saying, "Weren't people forbidden to make vows?" The Prophet (ﷺ) said, 'A vow neither hastens nor delays anything, but by the making of vows, some of the wealth of a miser is taken out}}
\hadithdefcmd{bukhari}{6693}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ النَّذْرِ وَقَالَ ‏ "‏ إِنَّهُ لاَ يَرُدُّ شَيْئًا، وَلَكِنَّهُ يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏‏.‏\hadithno{6693}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) forbade the making of vows and said, "It (a vow) does not prevent anything (that has to take place), but the property of a miser is spent (taken out) with it}}
\hadithdefcmd{bukhari}{6694}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَأْتِي ابْنَ آدَمَ النَّذْرُ بِشَىْءٍ لَمْ يَكُنْ قُدِّرَ لَهُ، وَلَكِنْ يُلْقِيهِ النَّذْرُ إِلَى الْقَدَرِ قَدْ قُدِّرَ لَهُ، فَيَسْتَخْرِجُ اللَّهُ بِهِ مِنَ الْبَخِيلِ، فَيُؤْتِي عَلَيْهِ مَا لَمْ يَكُنْ يُؤْتِي عَلَيْهِ مِنْ قَبْلُ ‏"‏‏.‏\hadithno{6694}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah says, 'The vow, does not bring about for the son of Adam anything I have not decreed for him, but his vow may coincide with what has been decided for him, and by this way I cause a miser to spend of his wealth. So he gives Me (spends in charity) for the fulfillment of what has been decreed for him what he would not give Me before but for his vow}}
\hadithdefcmd{bukhari}{6695}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي أَبُو جَمْرَةَ، حَدَّثَنَا زَهْدَمُ بْنُ مُضَرِّبٍ، قَالَ سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُكُمْ قَرْنِي، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ ـ قَالَ عِمْرَانُ لاَ أَدْرِي ذَكَرَ ثِنْتَيْنِ أَوْ ثَلاَثًا بَعْدَ قَرْنِهِ ـ ثُمَّ يَجِيءُ قَوْمٌ يَنْذُرُونَ وَلاَ يَفُونَ، وَيَخُونُونَ وَلاَ يُؤْتَمَنُونَ، وَيَشْهَدُونَ وَلاَ يُسْتَشْهَدُونَ، وَيَظْهَرُ فِيهِمُ السِّمَنُ ‏"‏‏.‏\hadithno{6695}\hadithtrans{Narrated Zahdam bin Mudarrab:`Imran bin Hussain said, "The Prophet (ﷺ) said, 'The best of you (people) are my generation, and the second best will be those who will follow them, and then those who will follow the second generation." `Imran added, "I do not remember whether he mentioned two or three (generations) after his generation. He added, 'Then will come some people who will make vows but will not fulfill them; and they will be dishonest and will not be trustworthy, and they will give their witness without being asked to give their witness, and fatness will appear among them}}
\hadithdefcmd{bukhari}{6696}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مَالِكٌ، عَنْ طَلْحَةَ بْنِ عَبْدِ الْمَلِكِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ، وَمَنْ نَذَرَ أَنْ يَعْصِيَهُ فَلاَ يَعْصِهِ ‏"‏‏.‏\hadithno{6696}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Whoever vows that he will be obedient to Allah, should remain obedient to Him; and whoever made a vow that he will disobey Allah, should not disobey Him}}
\hadithdefcmd{bukhari}{6697}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، قَالَ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ فِي الْجَاهِلِيَّةِ أَنْ أَعْتَكِفَ لَيْلَةً فِي الْمَسْجِدِ الْحَرَامِ‏.‏ قَالَ ‏ "‏ أَوْفِ بِنَذْرِكَ ‏"‏‏.‏\hadithno{6697}\hadithtrans{Narrated Ibn `Umar:`Umar said "O Allah's Messenger (ﷺ)! I vowed to perform I`tikaf for one night in Al-Masjid-al-Haram, during the Pre-Islamic Period of ignorance (before embracing Islam). "The Prophet (ﷺ) said, "Fulfill your vow." Ibn `Umar said to the lady, "Pray on her behalf." Ibn `Abbas said the same}}
\hadithdefcmd{bukhari}{6698}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ سَعْدَ بْنَ عُبَادَةَ الأَنْصَارِيَّ اسْتَفْتَى النَّبِيَّ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ، فَتُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ‏.‏ فَأَفْتَاهُ أَنْ يَقْضِيَهُ عَنْهَا، فَكَانَتْ سُنَّةً بَعْدُ‏.‏\hadithno{6698}\hadithtrans{Narrated Sa`id bin 'Ubada Al-Ansari:that he consulted the Prophet (ﷺ) about a vow that had been made by his mother who died without fulfilling it. The Prophet (ﷺ) gave his verdict that he should fulfill it on her behalf. The verdict became Sunna (i.e. the Prophet's tradition)}}
\hadithdefcmd{bukhari}{6699}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَتَى رَجُلٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ لَهُ إِنَّ أُخْتِي نَذَرَتْ أَنْ تَحُجَّ وَإِنَّهَا مَاتَتْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ كَانَ عَلَيْهَا دَيْنٌ أَكُنْتَ قَاضِيَهُ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَاقْضِ اللَّهَ، فَهْوَ أَحَقُّ بِالْقَضَاءِ ‏"‏‏.‏\hadithno{6699}\hadithtrans{Narrated Ibn `Abbas:A man came to the Prophet (ﷺ) and said to him, "My sister vowed to perform the Hajj, but she died (before fulfilling it)." The Prophet (ﷺ) said, "Would you not have paid her debts if she had any?" The man said, "Yes." The Prophet (ﷺ) said, "So pay Allah's Rights, as He is more entitled to receive His rights}}
\hadithdefcmd{bukhari}{6700}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ مَالِكٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ الْمَلِكِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ، وَمَنْ نَذَرَ أَنْ يَعْصِيَهُ فَلاَ يَعْصِهِ ‏"‏‏.‏\hadithno{6700}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Whoever vowed to be obedient to Allah, must be obedient to Him; and whoever vowed to be disobedient to Allah, should not be disobedient to Him}}
\hadithdefcmd{bukhari}{6701}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ حُمَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ لَغَنِيٌّ عَنْ تَعْذِيبِ هَذَا نَفْسَهُ ‏"‏‏.‏ وَرَآهُ يَمْشِي بَيْنَ ابْنَيْهِ‏.‏ وَقَالَ الْفَزَارِيُّ عَنْ حُمَيْدٍ حَدَّثَنِي ثَابِتٌ عَنْ أَنَسٍ\hadithno{6701}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Allah is not in need of this man) torturing himself," when he saw the man walking between his two sons (who were supporting him)}}
\hadithdefcmd{bukhari}{6702}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً يَطُوفُ بِالْكَعْبَةِ بِزِمَامٍ أَوْ غَيْرِهِ، فَقَطَعَهُ‏.‏\hadithno{6702}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) saw a man performing Tawaf around the Ka`ba, tied with a rope or something else (while another person was holding him). The Prophet (ﷺ) cut that rope off}}
\hadithdefcmd{bukhari}{6703}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي سُلَيْمَانُ الأَحْوَلُ، أَنَّ طَاوُسًا، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ وَهْوَ يَطُوفُ بِالْكَعْبَةِ بِإِنْسَانٍ يَقُودُ إِنْسَانًا بِخِزَامَةٍ فِي أَنْفِهِ، فَقَطَعَهَا النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ، ثُمَّ أَمَرَهُ أَنْ يَقُودَهُ بِيَدِهِ\hadithno{6703}\hadithtrans{Narrated Ibn `Abbas:While performing the Tawaf around the Ka`ba, the Prophet (ﷺ) passed by a person leading another person by a hair-rope nose-ring in his nose. The Prophet (ﷺ) cut the hair-rope nose-ring off with his hand and ordered the man to lead him by the hand}}
\hadithdefcmd{bukhari}{6704}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ إِذَا هُوَ بِرَجُلٍ قَائِمٍ فَسَأَلَ عَنْهُ فَقَالُوا أَبُو إِسْرَائِيلَ نَذَرَ أَنْ يَقُومَ وَلاَ يَقْعُدَ وَلاَ يَسْتَظِلَّ وَلاَ يَتَكَلَّمَ وَيَصُومَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مُرْهُ فَلْيَتَكَلَّمْ وَلْيَسْتَظِلَّ وَلْيَقْعُدْ وَلْيُتِمَّ صَوْمَهُ ‏"‏‏.‏ قَالَ عَبْدُ الْوَهَّابِ حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6704}\hadithtrans{Narrated Ibn `Abbas:While the Prophet (ﷺ) was delivering a sermon, he saw a man standing, so he asked about that man. They (the people) said, "It is Abu Israil who has vowed that he will stand and never sit down, and he will never come in the shade, nor speak to anybody, and will fast.'' The Prophet (ﷺ) said, "Order him to speak and let him come in the shade, and make him sit down, but let him complete his fast}}
\hadithdefcmd{bukhari}{6705}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، حَدَّثَنَا حَكِيمُ بْنُ أَبِي حُرَّةَ الأَسْلَمِيُّ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ سُئِلَ عَنْ رَجُلٍ، نَذَرَ أَنْ لاَ، يَأْتِيَ عَلَيْهِ يَوْمٌ إِلاَّ صَامَ، فَوَافَقَ يَوْمَ أَضْحًى أَوْ فِطْرٍ‏.‏ فَقَالَ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ، لَمْ يَكُنْ يَصُومُ يَوْمَ الأَضْحَى وَالْفِطْرِ، وَلاَ يَرَى صِيَامَهُمَا‏.‏\hadithno{6705}\hadithtrans{Narrated `Abdullah bin `Umar:that he was asked about a man who had vowed that he would fast all the days of his life then the day of `Id al Adha or `Id-al-Fitr came. `Abdullah bin `Umar said: You have indeed a good example in Allah's Messenger (ﷺ). He did not fast on the day of `Id al Adha or the day of `Id-al-Fitr, and we do not intend fasting on these two days}}
\hadithdefcmd{bukhari}{6706}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ يُونُسَ، عَنْ زِيَادِ بْنِ جُبَيْرٍ، قَالَ كُنْتُ مَعَ ابْنِ عُمَرَ فَسَأَلَهُ رَجُلٌ فَقَالَ نَذَرْتُ أَنْ أَصُومَ كُلَّ يَوْمِ ثَلاَثَاءَ أَوْ أَرْبِعَاءَ مَا عِشْتُ، فَوَافَقْتُ هَذَا الْيَوْمَ يَوْمَ النَّحْرِ‏.‏ فَقَالَ أَمَرَ اللَّهُ بِوَفَاءِ النَّذْرِ، وَنُهِينَا أَنْ نَصُومَ يَوْمَ النَّحْرِ‏.‏ فَأَعَادَ عَلَيْهِ فَقَالَ مِثْلَهُ، لاَ يَزِيدُ عَلَيْهِ‏.‏\hadithno{6706}\hadithtrans{Narrated Ziyad bin Jubair:I was with Ibn `Umar when a man asked him, "I have vowed to fast every Tuesday or Wednesday throughout my life and if the day of my fasting coincided with the day of Nahr (the first day of `Id-al- Adha), (What shall I do?)" Ibn `Umar said, "Allah has ordered the vows to be fulfilled, and we are forbidden to fast on the day of Nahr." The man repeated his question and Ibn `Umar repeated his former answer, adding nothing more}}
\hadithdefcmd{bukhari}{6707}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ أَبِي الْغَيْثِ، مَوْلَى ابْنِ مُطِيعٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ فَلَمْ نَغْنَمْ ذَهَبًا وَلاَ فِضَّةً إِلاَّ الأَمْوَالَ وَالثِّيَابَ وَالْمَتَاعَ، فَأَهْدَى رَجُلٌ مِنْ بَنِي الضُّبَيْبِ يُقَالُ لَهُ رِفَاعَةُ بْنُ زَيْدٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم غُلاَمًا يُقَالُ لَهُ مِدْعَمٌ، فَوَجَّهَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى وَادِي الْقُرَى حَتَّى إِذَا كَانَ بِوَادِي الْقُرَى بَيْنَمَا مِدْعَمٌ يَحُطُّ رَحْلاً لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا سَهْمٌ عَائِرٌ فَقَتَلَهُ، فَقَالَ النَّاسُ هَنِيئًا لَهُ الْجَنَّةُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَلاَّ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ الشَّمْلَةَ الَّتِي أَخَذَهَا يَوْمَ خَيْبَرَ مِنَ الْمَغَانِمِ، لَمْ تُصِبْهَا الْمَقَاسِمُ، لَتَشْتَعِلُ عَلَيْهِ نَارًا ‏"‏‏.‏ فَلَمَّا سَمِعَ ذَلِكَ النَّاسُ جَاءَ رَجُلٌ بِشِرَاكٍ أَوْ شِرَاكَيْنِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ شِرَاكٌ مِنْ نَارٍ ـ أَوْ ـ شِرَاكَانِ مِنْ نَارٍ ‏"‏‏.‏\hadithno{6707}\hadithtrans{Narrated Abu Huraira:We went out in the company of Allah's Messenger (ﷺ) on the day of (the battle of) Khaibar, and we did not get any gold or silver as war booty, but we got property in the form of things and clothes. Then a man called Rifa`a bin Zaid, from the tribe of Bani Ad-Dubaib, presented a slave named Mid`am to Allah's Apostle. Allah's Messenger (ﷺ) headed towards the valley of Al-Qura, and when he was in the valley of Al- Qura an arrow was thrown by an unidentified person, struck and killed Mid`am who was making a she-camel of Allah's Messenger (ﷺ) kneel down. The people said, "Congratulations to him (the slave) for gaining Paradise." Allah's Messenger (ﷺ) said, "No! By Him in Whose Hand my soul is, for the sheet which he stole from the war booty before its distribution on the day of Khaibar, is now burning over him." When the people heard that, a man brought one or two Shiraks (leather straps of shoes) to the Prophet. The Prophet (ﷺ) said, "A Shirak of fire, or two Shiraks of fire}}
